Changelog
---------

0.2.0 (2016-12-13)
~~~~~~~~~~~~~~~~~~~

- Adds an 'outstanding' property to the invoice item collection.
  [href]

- Adds the ability to cancel an occasion.
  [href]

- Make sure direct bookings have the correct cost set.
  [href]

0.1.2 (2016-12-01)
~~~~~~~~~~~~~~~~~~~

- Adds columns for payment/booking costs.
  [href]

- Adds the ability to limit the number of matched bookings.
  [href]

- Adds the ability to create invoices for bookings.
  [href]

- Fixes matching resulting in an error in certain constellations.
  [href]

0.1.1 (2016-11-25)
~~~~~~~~~~~~~~~~~~~

- Adds a finalized flag to the periods which indicates that the period
  transitioned from the booking to the payment phase.
  [href]

- Adds the ability to accept/cancel bookings in a confirmed period.
  [href]

- Adds an accepted booking count to the occasion, along with properties to
  check for operable and/or full occasions.
  [href]

- Adds a custom data column to the period.
  [href]

- Introduces the ability to configure custom scoring functions for matching.
  [href]

- Starring a booking no longer leads to a cascade of updates.
  [href]

0.1.0 (2016-11-18)
~~~~~~~~~~~~~~~~~~~

- Periods now have a confirmed flag. Confirmed periods can be booked directly,
  while unconfirmed bookings an be booked through the wishlist and matched
  using the matching algorithm.
  [href]

- Adds an implementation of Deferred Acceptance as a matching algorithm.
  [href]

- Introduces a happiness function on the attendee which returns a value
  between 0.0 and 1.0 depending on how happy the attendee is assumed to be
  with the bookings confirmed for the given period.
  [href]

- Adds the denormalized period_id to the bookings.
  [href]

- Make sure all models are hashable.
  [href]

0.0.11 (2016-11-02)
~~~~~~~~~~~~~~~~~~~

- Adds the ability to star/unstar a booking.
  [href]

- Adds the ability to switch the username or period on the bookings collection.
  [href]

- Adds the ability to filter the bookings by username or period.
  [href]

- Includes a count method for bookings per user.
  [href]

- Adds an attendee model.
  [href]

0.0.10 (2016-10-20)
~~~~~~~~~~~~~~~~~~~

- Reworks the datamodel to include a period linked to the occasion/bookings.
  [href]

0.0.9 (2016-10-17)
~~~~~~~~~~~~~~~~~~~

- Improves the performance of the used_tags method.
  [href]

0.0.8 (2016-10-14)
~~~~~~~~~~~~~~~~~~~

- Adds the ability to filter the activites by one or many owners.
  [href]

- Adds the ability to filter the activites by age ranges.
  [href]

0.0.7 (2016-10-10)
~~~~~~~~~~~~~~~~~~~

- Adds the ability to filter activites by the duration of their occasions.
  [href]

- Adds a db constraint ensuring that an occasion always starts before it ends.
  [href]

- Adds an archived state to occasions.
  [href]

0.0.6 (2016-10-06)
~~~~~~~~~~~~~~~~~~~

- Adds a reporter column to activites.
  [href]

0.0.5 (2016-10-04)
~~~~~~~~~~~~~~~~~~~

- Occasions and bookings can no longer be orphaned.
  [href]

- Location is now optional.
  [href]

- Adds an occasion collection.
  [href]

0.0.4 (2016-10-03)
~~~~~~~~~~~~~~~~~~~

- Overhauls the occasion model.
  [href]

0.0.3 (2016-09-29)
~~~~~~~~~~~~~~~~~~~

- Adds the ability to directly access the user object from the activity.
  [href]

0.0.2 (2016-09-26)
~~~~~~~~~~~~~~~~~~~

- Adds the ability to override the query base on a subclass.
  [href]

- Adds the ability to filter the collection by state.
  [href]

- Adds the ability to get the set of used activity tags.
  [href]

0.0.1 (2016-09-22)
~~~~~~~~~~~~~~~~~~~

- Initial Release
